summaryrefslogtreecommitdiff
path: root/sysdeps/libm-i387/s_floorl.S
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/libm-i387/s_floorl.S')
-rw-r--r--sysdeps/libm-i387/s_floorl.S26
1 files changed, 14 insertions, 12 deletions
diff --git a/sysdeps/libm-i387/s_floorl.S b/sysdeps/libm-i387/s_floorl.S
index 7b7cff777a..c2bf091d73 100644
--- a/sysdeps/libm-i387/s_floorl.S
+++ b/sysdeps/libm-i387/s_floorl.S
@@ -9,23 +9,25 @@
RCSID("$NetBSD: $")
ENTRY(__floorl)
- pushl %ebp
- movl %esp,%ebp
+ fldt 4(%esp)
subl $8,%esp
- fstcw -4(%ebp) /* store fpu control word */
- movw -4(%ebp),%dx
- orw $0x0400,%dx /* round towards -oo */
- andw $0xf7ff,%dx
- movw %dx,-8(%ebp)
- fldcw -8(%ebp) /* load modified control word */
+ fstcw 4(%esp) /* store fpu control word */
- fldt 8(%ebp) /* round */
- frndint
+ /* We use here %edx although only the low 1 bits are defined.
+ But none of the operations should care and they are faster
+ than the 16 bit operations. */
+ movl $0x400,%edx /* round towards -oo */
+ orl 4(%esp),%edx
+ andl $0xf7ff,%edx
+ movl %edx,(%esp)
+ fldcw (%esp) /* load modified control word */
- fldcw -4(%ebp) /* restore original control word */
+ frndint /* round */
- leave
+ fldcw 4(%esp) /* restore original control word */
+
+ addl $8,%esp
ret
END (__floorl)
weak_alias (__floorl, floorl)